![PyPI](https://img.shields.io/pypi/v/hypha.svg?style=popout)
# Hypha

Hypha is an application framework for large-scale data management and AI model serving, it allows creating computational platforms consists of computational and user interface components.

Hypha server act as a hub for connecting different components through [imjoy-rpc](https://github.com/imjoy-team/imjoy-rpc).


See https://ha.amun.ai for more detailed usage.
